/* Special definitions for Guavac, processed by autoheader.
   Copyright (C) 1996 Free Software Foundation, Inc.
   Joerg Heitkoetter <joke@Germany.EU.net>, 1996.
*/

/* Define to the name of the distribution.  */
#undef PRODUCT

/* Define to 1 if ANSI function prototypes are usable.  */
#undef PROTOTYPES

/* Define to int if rlim_t is not defined in sys/resource.h */
#undef rlim_t

/* Define to struct sigaltstack if stack_t is not defined in sys/signal.h */
#undef stack_t

/* Define to 1 if using stack overflow detection.  */
#undef USE_STACKOVF

/* Define to the version of the distribution.  */
#undef VERSION

/* Define to 1 for better use of the debugging malloc library.  See 
   site ftp.antaire.com in antaire/src, file dmalloc/dmalloc.tar.gz.  */
#undef WITH_DMALLOC

/* Define if we have to include std/bastring.cc in order to get string
   symbols for types other than char defined */
#undef NEED_BASTRING_CC

/* Define if we must explicitly instantiate wstring::nilRep */
#undef NEED_EXPLICIT_UNISTRING_NILREP

/* Keep autoheader happy... ;-)  */
#undef GNUFLAGS
#undef TEMPLATEFLAGS
#undef CXX
#undef CFLAGS
